package ticket

import (
	"encoding/json"
	"github.com/ClickHouse/clickhouse-go/v2/lib/driver"
	"google.golang.org/protobuf/types/known/timestamppb"
	"time"
)

func (x *Ticket) Scan(row driver.Rows) error {
	var (
		from       map[string]string
		createdAt  time.Time
		updatedAt  time.Time
		messageIds []string
		err        error
	)

	if err = row.Scan(
		&x.TicketId,
		&x.ThreadId,
		&x.To,
		&from,
		&x.Flags,
		&x.Meta,
		&x.Tags,
		&createdAt,
		&updatedAt,
		&messageIds,
	); err != nil {
		return err
	}

	x.From = &EmailAddress{
		Address: from["address"],
		Name:    from["name"],
	}

	x.CreatedAt = timestamppb.New(createdAt)
	x.UpdatedAt = timestamppb.New(updatedAt)

	if len(messageIds) > 0 {
		if d, err := json.Marshal(messageIds); err == nil {
			x.Meta["message_ids"] = string(d)
		}
	}

	return nil
}
